

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.media.*;
import javax.media.format.*;
import javax.media.control.*;
import javax.media.protocol.*;
import java.applet.Applet;
import java.awt.BorderLayout;
import java.net.URL;

/**
 * @author Horst Eidenberger (hme@ims.tuwien.ac.at), adaptation: Heinrich
 *         Hussmann
 * @version 1
 */

class VideoPlayerFrame extends JFrame implements ControllerListener {

	Processor p = null;
	Player player = null;

	public VideoPlayerFrame(String file) {
		setTitle("Grey Effect");
		addWindowListener(new WindowAdapter() {
			public void windowClosing(WindowEvent event) {
				p.stop();
				p.deallocate();
				System.exit(0);
			}
		});
		try {
			p = Manager.createProcessor(new MediaLocator(file));
			p.addControllerListener(this);
			p.configure();
		} catch (Exception e) {
			System.out.println("Can't configure: " + e.getMessage());
		}
	}

	public synchronized void controllerUpdate(ControllerEvent event) {

		if (event instanceof ConfigureCompleteEvent) {
			TrackControl[] tracks = p.getTrackControls();

			boolean found = false;
			for (int i = 0; i < tracks.length; i++) {
				if (!found && tracks[i].getFormat() instanceof VideoFormat) {
					Codec[] videoConversion = new Codec[] {
							new com.sun.media.codec.video.cinepak.JavaDecoder(),
							new GreyEffect() };

					try {
						tracks[i].setCodecChain(videoConversion);
						p.setContentDescriptor(new ContentDescriptor(
								ContentDescriptor.RAW));
						found = true;
					} catch (Exception e) {
						System.out.println("Can't set processing chain: "
								+ e.getMessage());
					}
				} 
			}

			if (found)
				p.realize();
			else {
				System.out.println("Attempt to realize processor failed.");
				System.exit(-1);
			}

		}

		else if (event instanceof RealizeCompleteEvent) {
			try {
				player = Manager.createRealizedPlayer(p.getDataOutput());
				getContentPane().setLayout(new BorderLayout());
				getContentPane().add(player.getControlPanelComponent(),
						BorderLayout.SOUTH);
				getContentPane().add(player.getVisualComponent(),
						BorderLayout.NORTH);
				
				setSize(350, 300);
				setVisible(true);

				player.start();
				p.start();
			} catch (Exception e) {
				System.out.println("Can't create player: " + e.getMessage());
			}
		}

		else if (event instanceof EndOfMediaEvent) {
			player.stop();
			p.stop();

			p.setMediaTime(new Time(0));
			player.setMediaTime(new Time(0));
			player.start();
			p.start();
		}
	}

	public static void main(String[] argv) {
		String file = "http://www.medien.ifi.lmu.de/lehre/ss08/mt/uebungen/blatt4video.avi";
		VideoPlayerFrame pf = new VideoPlayerFrame(file);
	}

}
